pub struct OrthoProj<T: Clone> { /* private fields */ }Expand description
An orthographic image
Images are square, with the globe in the middle. Create one with a size of 500x500, where
all pixels are set to 0, centred on Rome:
Examples
use orthoproj::OrthoProj;
let mut image = OrthoProj::new(500, 41.89889, 12.47337, 0);We can then set pixels on this image, based on their lat/lon
image.set(51.50791, -0.12786, 1);You can then loop over all the pixels, getting the current value.
Implementations
Sourceimpl<T: Clone> OrthoProj<T>
impl<T: Clone> OrthoProj<T>
Sourcepub fn new(size: u32, lat: f32, lon: f32, default: T) -> Self
pub fn new(size: u32, lat: f32, lon: f32, default: T) -> Self
Create a new orthographic projection with width & height of size, centred on lat and
lon. default is the default value
Sourcepub fn new_with_bg(size: u32, lat: f32, lon: f32, bg: T, surface: T) -> Self
pub fn new_with_bg(size: u32, lat: f32, lon: f32, bg: T, surface: T) -> Self
Create a new OrthoProj, size and lon/lat, but the background (non-sphere) is bg,
and surface is used for values on the sphere.